# -*- coding: latin-1 -*-
###############################################################################
# Copyright © 2018 NetApp, Inc. All Rights Reserved.
#
# CONFIDENTIALITY NOTICE:  THIS SOFTWARE CONTAINS CONFIDENTIAL INFORMATION OF
# NETAPP, INC. USE, DISCLOSURE OR REPRODUCTION IS PROHIBITED WITHOUT THE PRIOR
# EXPRESS WRITTEN PERMISSION OF NETAPP, INC.
###############################################################################


from requests.auth import HTTPBasicAuth
from oauthlib.oauth2 import BackendApplicationClient, LegacyApplicationClient
from requests_oauthlib.oauth2_session import OAuth2Session
from authtools.config import Config


def get_client_credentials_session(token_endpoint: str, client_id: str, client_secret: str, scope=None, verify=True):
    """
    Get a request session with a bearer token requested using the client credentials grant type.
    :param token_endpoint: The token endpoint of the auth service
    :param client_id: The ID of the client registered with the authentication server
    :param client_secret: The secret of the client registered with the authentication server.
    :param scope: List of scopes whcih should be included in the session's access token
    :param verify: True to perform SSL verification for requests from this session, otherwise false
    :return: A Requests-Session instance extended to provide bearer authentication
    """

    auth = HTTPBasicAuth(client_id, client_secret)
    client = BackendApplicationClient(client_id=client_id, scope=scope)
    session = OAuth2Session(client=client)
    session.fetch_token(token_url=token_endpoint, auth=auth, verify=verify)
    return session


def get_resource_owner_password_session(token_endpoint: str, client_id: str, username: str, password: str,
                                        client_secret: str = None, scope=None, verify=True):
    """
    Get a request session with a bearer token requested using the resource owner grant type.
    :param token_endpoint: The token endpoint of the auth service
    :param client_id:  The ID of the client registered with the authentication server
    :param username: The username of the resource owner to authenticate with
    :param password: The password of the resource owner to authenticate with
    :param client_secret: The secret of the client registered with the authentication server. May be optional
    :param scope: List of scopes whcih should be included in the session's access token
    :param verify: True to perform SSL verification for requests from this session, otherwise false
    :return: A Requests-Session instance extended to provide bearer authentication
    """
    auth = HTTPBasicAuth(client_id, client_secret)
    client = LegacyApplicationClient(client_id=client_id, scope=scope)
    session = OAuth2Session(client=client)
    session.fetch_token(token_url=token_endpoint, auth=auth, username=username, password=password, verify=verify)
    return session


"""
Get a request session for a standard MNode service with default client configuration.
:param scope: List of scopes whcih should be included in the session's access token
:param verify: True to perform SSL verification for requests from this session, otherwise false
:return: A Requests-Session instance extended to provide bearer authentication
"""
def get_mnode_service_session(scope=None, verify=True) -> OAuth2Session:
    secret = Config.getClientSecret()
    token_url = Config.getTokenUrl()

    session = get_client_credentials_session(token_endpoint=token_url,
        client_id = Config.AUTH_CLIENT_ID, client_secret = secret,
        scope=scope, verify=verify)
    return session
